"""
This module contains definitions of the HTTP protocol.
"""

FORM_CONTENT_TYPES = [
    'application/x-www-form-urlencoded',
    'multipart/form-data'
]

METHODS = {
    "get",
    "put",
    "post",
    "delete",
    "options",
    "head",
    "patch",
    "trace"
}
